# SAP Data Intelligence Utilites (sdi_utils) by thhapke

This package includes a couple of helpers that ease the development of operators for use with 
 **SAP Data Intelligence (SAP DI)**.  
 
 * [**gensolution**](./gensolution.md) for generating solution packages from locally developed operators. 
 *  [**textfield_parser**](./textfield_parser.md) that parses textfields that could contain lists, maps, list of maps,  etc. 
 *  [**set_logging**](./set_logging.md) for channeling logging output to a string for tap wiring it with separate monitor
 *  [**tprogress**](./tprogress.md) for a simple time keeping to check performance of certain operators (tasks)

 ## Installation
 ```
 pip install sdi_utils
 ```
 
 ## Github
 [github repository](https://github.com/thhapke/sdi_utils)